@@ -44,7 +44,7 @@ def TOP10(user_id):
     Result = []
     M = 0
     for i in Score :
-        if((len(ratings[(ratings['user_id']==user_id) & (ratings['item_id']==i[1])]))==0):
+        if((len(ratings[(ratings['user_id']==user_id) & (ratings['item_id']==int(i[1]))]))==0):
             Result.append(i[1])
         M+=1
         if(M==10 or M==len(Score)):
